@@ -6,12 +6,12 @@ ct.int   <- unique(extractHeader(core_426$hdr, "RescaleIntercept"))
 HU_426 <- lapply(core_426$img, function(x) x*ct.slope + ct.int)
 
 # Use coreCT::conv to convert Hounsfield Units to densities and quantify component masses, volumes
-materials <- conv(HU_426, pixelA = voxDims("core_426")$pixelArea.mm2, thickness = voxDims("core_426")$thickness.mm)
+materials <- convert(HU_426, pixelA = voxDims("core_426")$pixelArea.mm2, thickness = voxDims("core_426")$thickness.mm)
 
 plot(-depth ~ peat.cm3, data = materials, xlab = "Peat volume (cm3; per slice)", ylab = "Depth (cm)")
 
 ## ---- message=FALSE, warning=FALSE, results = "hide"---------------------
-materials <- convDir("core_426")
+materials <- convertDir("core_426")
 
 plot(-depth ~ peat.cm3, data = materials, xlab = "Peat volume (cm3; per slice)", ylab = "Depth (cm)")
 
@@ -22,7 +22,7 @@ names(HUfreq)
 HUfreq$splits
 
 ## ---- message=FALSE, warning=FALSE, results = "hide"---------------------
-rootChars <- rootSizeDir("core_426", diameter.classes = c(1, 2.5, 10))
+rootChars <- getRootsDir("core_426", diameter.classes = c(1, 2.5, 10))
 
 plot(-depth ~ structures, data = rootChars, xlab = "Root structures (per slice)", ylab = "Depth (cm)")
 
